@@ -136,7 +136,9 @@ def parse(adf, carryForward=None):
     try: 
         result=fn(data, carryForward)                           #Ex: listItem(adf["content"], 1)                
         return result
-    except: return ''
+    except:
+        if gDebug: print("Unable to Parse: " + type)
+        return ''
 
 def startParsing(adf, debug=False, runReplacers=True, bulletDecor=None):
     global gDebug, gBulletDecor
@@ -145,5 +147,5 @@ def startParsing(adf, debug=False, runReplacers=True, bulletDecor=None):
     result = parse(adf)                                         #Do the Parsing
     if runReplacers:                                            #Run Replacers
         for r in replacers:        
-            result=result.replace(r, '\n')    
+            result=result.replace(r, ' ')    
     return result                                               #Return result
